"""
    QuaO Project project_header.py Copyright © CITYNOW Co. Ltd. All rights reserved.
"""


class ProjectHeader:
    def __init__(self, name: str, value: str):
        self.name = name
        self.value = value
